==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/messages/lt/base.php <==
<?php

return [
    '<strong>Latest</strong> updates' => '<strong>Naujausi</strong> atnaujinimai',
    'Account settings' => 'Paskyros nustatymai',
    'Administration' => 'Administravimas',
    'All' => 'Visi',
    'Back' => 'Atgal',
    'Back to dashboard' => 'Atgal į pradžios langa',
    'Cancel' => 'Atšaukti',
    'Choose language:' => 'Pasirinkti kalbą:',
    'Close' => 'Uždaryti',
    'Collapse' => 'Sutraukti',
    'Confirm' => 'Patvirtinti',
    'Delete' => 'Ištrinti',
    'Edit' => 'Taisyti',
    'Error' => 'Klaida',
    'Expand' => 'Išplėsti',
    'It looks like you may have taken the wrong turn.' => 'Atrodo, einate ne ta linkme.',
    'Language' => 'Kalba',
    'Login' => 'Prisijungti',
    'Logout' => 'Atsijungti',
    'Menu' => 'Meniu',
    'Module is not enabled on this content container!' => 'Modulis šioje turinio talpykloje negalimas!',
    'My profile' => 'Mano profilis',
    'New profile image' => 'Nauja profilio nuotrauka',
    'Next' => 'Kitas',
    'Oooops...' => 'Oi...',
    'Save' => 'Išsaugoti',
    'Saved' => 'Išsaugota',
    'Search' => 'Paieška',
    '<strong>Confirm</strong> Action' => '',
    '<strong>Mail</strong> summary' => '',
    'Actions' => '',
    'Add:' => '',
    'Allow' => '',
    'Allow content from external source' => '',
    'Always allow content from this provider!' => '',
    'An error occurred while handling your last action. (Handler not found).' => '',
    'An unexpected error occurred while loading the search result.' => '',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => '',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => '',
    'An unknown error occurred while uploading.' => '',
    'An unknown error occurred while uploading. Hint: check your upload_max_filesize and post_max_size php settings.' => '',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => '',
    'Copy to clipboard' => '',
    'Could not find content of addon!' => '',
    'Could not find requested page.' => '',
    'Default' => '',
    'Deny' => '',
    'Do you really want to perform this action?' => '',
    'Do you want to enable content from \'{urlPrefix}\'?' => '',
    'Error while running your last action (Invalid request method).' => '',
    'Error:' => '',
    'Export' => '',
    'Info:' => '',
    'Invalid request method!' => '',
    'Loading...' => '',
    'Logo of {appName}' => '',
    'No error information given.' => '',
    'Open' => '',
    'Please type at least 3 characters' => '',
    'Please type at least {count} characters' => '',
    'Powered by {name}' => '',
    'Profile dropdown' => '',
    'Profile picture of {displayName}' => '',
    'Select Me' => '',
    'Show less' => '',
    'Show more' => '',
    'Some files could not be uploaded:' => '',
    'Stop impersonation' => '',
    'Text could not be copied to clipboard' => '',
    'Text has been copied to clipboard' => '',
    'The date has to be in the past.' => '',
    'The file has been deleted.' => '',
    'The requested resource could not be found.' => '',
    'The space has been archived.' => '',
    'The space has been unarchived.' => '',
    'Time Zone' => '',
    'Toggle comment menu' => '',
    'Toggle panel menu' => '',
    'Toggle post menu' => '',
    'Toggle stream entry menu' => '',
    'Unsaved changes will be lost. Do you want to proceed?' => '',
    'Unsubscribe' => '',
    'Upload' => '',
    'Upload file' => '',
    'You are not allowed to run this action.' => '',
    '{nFormatted}B' => '',
    '{nFormatted}K' => '',
    '{nFormatted}M' => '',
];

==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/messages/lt/base.php <==
<?php

return [
    '<strong>Latest</strong> updates' => '<strong>Naujausi</strong> atnaujinimai',
    'Administration' => 'Administravimas',
    'All' => 'Visi',
    'Back' => 'Atgal',
    'Back to dashboard' => 'Atgal į pradžios langa',
    'Cancel' => 'Atšaukti',
    'Choose language:' => 'Pasirinkti kalbą:',
    'Close' => 'Uždaryti',
    'Collapse' => 'Sutraukti',
    'Confirm' => 'Patvirtinti',
    'Delete' => 'Ištrinti',
    'Edit' => 'Taisyti',
    'Error' => 'Klaida',
    'Expand' => 'Išplėsti',
    'It looks like you may have taken the wrong turn.' => 'Atrodo, einate ne ta linkme.',
    'Language' => 'Kalba',
    'Login' => 'Prisijungti',
    'Logout' => 'Atsijungti',
    'Menu' => 'Meniu',
    'Module is not enabled on this content container!' => 'Modulis šioje turinio talpykloje negalimas!',
    'New profile image' => 'Nauja profilio nuotrauka',
    'Next' => 'Kitas',
    'Oooops...' => 'Oi...',
    'Save' => 'Išsaugoti',
    'Saved' => 'Išsaugota',
    'Search' => 'Paieška',
    'Settings' => 'Nustatymai',
    '<strong>Confirm</strong> Action' => '',
    '<strong>Mail</strong> summary' => '',
    'Actions' => '',
    'Add:' => '',
    'Allow' => '',
    'Allow content from external source' => '',
    'Always allow content from this provider!' => '',
    'An error occurred while handling your last action. (Handler not found).' => '',
    'An unexpected error occurred while loading the search result.' => '',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => '',
    'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => '',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => '',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => '',
    'Copy to clipboard' => '',
    'Could not find content of addon!' => '',
    'Could not find requested page.' => '',
    'Default' => '',
    'Deny' => '',
    'Do you really want to perform this action?' => '',
    'Do you want to enable content from \'{urlPrefix}\'?' => '',
    'Error while running your last action (Invalid request method).' => '',
    'Error:' => '',
    'Export' => '',
    'Info:' => '',
    'Invalid request method!' => '',
    'Loading...' => '',
    'Logo of {appName}' => '',
    'My Profile' => '',
    'No error information given.' => '',
    'Open' => '',
    'Please type at least 3 characters' => '',
    'Please type at least {count} characters' => '',
    'Powered by {name}' => '',
    'Profile dropdown' => '',
    'Profile picture of {displayName}' => '',
    'Search...' => '',
    'Select Me' => '',
    'Show less' => '',
    'Show more' => '',
    'Some files could not be uploaded:' => '',
    'Stop impersonation' => '',
    'Text could not be copied to clipboard' => '',
    'Text has been copied to clipboard' => '',
    'The date has to be in the past.' => '',
    'The file has been deleted.' => '',
    'The requested resource could not be found.' => '',
    'The space has been archived.' => '',
    'The space has been unarchived.' => '',
    'Time Zone' => '',
    'Toggle comment menu' => '',
    'Toggle panel menu' => '',
    'Toggle post menu' => '',
    'Toggle stream entry menu' => '',
    'Unsaved changes will be lost. Do you want to proceed?' => '',
    'Unsubscribe' => '',
    'Upload' => '',
    'Upload file' => '',
    'You are not allowed to run this action.' => '',
    'verify your upload_max_filesize and post_max_size php settings.' => '',
    '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '',
    '{attribute} must be a string (UUID) or null; {type} given.' => '',
    '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '',
    '{nFormatted}B' => '',
    '{nFormatted}K' => '',
    '{nFormatted}M' => '',
];
